
use $data/export_ready.dta, clear


bys siren iso3 cn8plus id_spell: egen count_obs=count(year)
drop if count_obs==1

gen log_price=log(export/qty)
gen log_qty=log(qty)

egen iso_g=group(iso3)
egen cn8_g=group(cn8plus)

egen id_panel=group(siren iso3 cn8plus)
egen siren_year=group(siren year)

bys id_panel id_spell: egen min_year_spell=min(year)


			***Merge with instruments

merge m:1 siren year min_year_spell using $data/instru_w0s.dta, keepusing(rer_dev_w0sn l_rer_dev_w0sn)
drop if _merge==2
drop _merge


			***Average gdp of the destination/origin countries

merge m:1 siren year using $data/gdp_controls.dta
drop if _merge==2
drop _merge

bys id_panel id_spell: egen mean_gdp_w_i=mean(gdp_w_import)
replace mean_gdp_w_i=0 if mean_gdp_w_i==.
replace gdp_w_import=mean_gdp_w_i if gdp_w_import==.
drop mean_gdp_w_i

bys id_panel id_spell: egen mean_gdp_w_i=mean(gdp_w_export)
replace mean_gdp_w_i=0 if mean_gdp_w_i==.
replace gdp_w_export=mean_gdp_w_i if gdp_w_export==.
drop mean_gdp_w_i


			***Info about entry

merge 1:1 siren cn8plus iso3 year using $data/entry.dta
drop if _merge==2
drop _merge


			***Bring cost shares (average from 1997-2007)


merge m:1 siren using $data/import_ratio_brn.dta, keepusing(ratio_costs)
replace ratio_costs=0 if _merge==1
drop if _merge==2
drop _merge

drop if ratio_costs==.




			***Bring market share (average during the span)


merge m:1 cn8plus using $data/cn8plus_to_hs6plus_1997_2010	
drop if _merge ==2
drop _merge
		
merge m:1 siren hs6plus iso3 year using $data/meanms_byspell_BACI.dta
drop if _merge==2
drop _merge
rename ms0 ms0_HS6
rename msbar msbar_HS6



foreach i of var rer_dev_w0s l_rer_dev_w0s {
replace `i'=0 if `i'==.
replace `i'=`i'*ratio_costs
}

g rer_dev_w0s_x_ms0_HS6=rer_dev_w0s*ms0_HS6


ivreghdfe log_qty  entry gdp_w_import gdp_w_export (log_price=rer_dev_w0s), ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren) first savefirst
estimates save pooled_estimates, replace
est restore _ivreg2_log_price
estimates save pooled_estimates, append


ivreghdfe log_qty  entry gdp_w_import gdp_w_export (log_price=rer_dev_w0s) if count_obs>6, ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren) first savefirst
estimates save pooled_estimates, append
est restore _ivreg2_log_price
estimates save pooled_estimates, append

ivreghdfe log_qty  entry gdp_w_import gdp_w_export (log_price=rer_dev_w0s l_rer_dev_w0s) if count_obs>6, ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren) first savefirst
estimates save pooled_estimates, append
est restore _ivreg2_log_price
estimates save pooled_estimates, append

ivreghdfe log_qty  entry gdp_w_import gdp_w_export (log_price=rer_dev_w0s rer_dev_w0s_x_ms0_HS6) if count_obs>6, ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren) first savefirst
estimates save pooled_estimates, append
est restore _ivreg2_log_price
estimates save pooled_estimates, append


reghdfe log_qty  entry gdp_w_import gdp_w_export rer_dev_w0s if count_obs>6, ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren)
estimates save pooled_estimates, append

reghdfe log_qty  entry gdp_w_import gdp_w_export rer_dev_w0s  l_rer_dev_w0sn if count_obs>6, ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren)
estimates save pooled_estimates, append


reghdfe log_qty entry gdp_w_import gdp_w_export log_price, ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren)
estimates save pooled_estimates, append

est use pooled_estimates.ster, number(1)
est store pooled_1	
est use pooled_estimates.ster, number(2)
est store pooled_1_FS
est use pooled_estimates.ster, number(3)
est store pooled_2	
est use pooled_estimates.ster, number(4)
est store pooled_2_FS
est use pooled_estimates.ster, number(5)
est store pooled_3	
est use pooled_estimates.ster, number(6)
est store pooled_3_FS
est use pooled_estimates.ster, number(7)
est store pooled_4	
est use pooled_estimates.ster, number(8)
est store pooled_4_FS	
est use pooled_estimates.ster, number(9)
est store pooled_RF1
est use pooled_estimates.ster, number(10)
est store pooled_RF2
est use pooled_estimates.ster, number(11)
est store pooled_OLS

		***TABLE 2

esttab pooled_1_FS pooled_2_FS pooled_3_FS pooled_4_FS pooled_RF1 pooled_RF2 using $tex/demand_pooled.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2)  compress replace
	
esttab pooled_OLS pooled_1 pooled_2 pooled_3 pooled_4 using $tex/demand_pooled.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2)   compress scalars(N widstat jp) sfmt(a1)  append
		

		***Cleaning sample for bootstrap

merge m:1 cn8plus using $data/cn8plus_to_product.dta
drop if _merge==2
drop _merge

keep if count_obs>6

keep log_qty log_price entry gdp_w_import gdp_w_export rer_dev_w0s id_spell siren iso_g cn8plus year product

**drop singletons
forvalues i=1/3 {
bys iso_g cn8plus year : egen nobs2=count(year)
drop if nobs2==1
drop nobs2
bys id_spell siren iso_g cn8plus : egen nobs=count(year)
drop if nobs==1 
drop nobs
}

save $data/boot_sample.dta, replace


		***Estimation with a single first stage, so wrong standard errors

preserve

hdfe log_qty log_price entry gdp_w_import gdp_w_export rer_dev_w0s, ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year) tol(1e-4) keepv(product) clear

quietly {

reg log_price entry gdp_w_import gdp_w_export rer_dev_w0s
predict log_price_rer, xb
reg log_qty entry gdp_w_import gdp_w_export i.product#c.log_price_rer
est sto e1
drop log_price_rer

}


esttab e1 using $tex/demand_byindustry.tex, replace ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) bracket wide   compress keep(*log_price_rer)	

restore

matrix b = e(b)

gen sigma_SFS=.
forvalues i=1/15 {
replace sigma_SFS=b[1,3+`i'] if product==`i'
}


		***Separate 2SLS regressions
		
gen sigma_2SLS=.		
		
forvalues i=1/15 {
		
qui ivreghdfe log_qty  entry gdp_w_import gdp_w_export (log_price=rer_dev_w0s) if product==`i', ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren) first

est sto e`i'
replace sigma_2SLS=_b[log_price]  if product==`i'

qui reghdfe log_qty  entry gdp_w_import gdp_w_export log_price if product==`i', ///
	absorb(id_spell#siren#iso_g#cn8plus iso_g#cn8plus#year, tol(1e-4))  cluster(siren)
est sto e`i'_ols

esttab e`i'_ols e`i' using $tex/demand_byindustry.tex, ///
	se starlevels(\sym{*} 0.10 \sym{**} 0.05 \sym{***} 0.01) b(a2) se(a2) wide scalars(N widstat)  compress  append keep(log_price)

}
		
		
keep product sigma_SFS sigma_2SLS
duplicates drop
replace sigma_SFS=-sigma_SFS
replace sigma_2SLS=-sigma_2SLS
gen sigma_agg=4.26

save $data/estimates_sigma.dta, replace

	
		
